@@ -5,3 +5,5 @@ from pydantic import Extra, BaseModel
 
 class Config(BaseModel, extra=Extra.ignore):
     htmlrender_browser: Optional[str] = "chromium"
+    htmlrender_download_host: Optional[str]
+    htmlrender_proxy_host: Optional[str]
